**Example 1: 批量删除企业组织成员**



Input: 

```
tccli organization DeleteOrganizationMembers --cli-unfold-argument  \
    --Uins 1
```

Output: 
```
{
    "Response": {
        "RequestId": "b46d2afe-6893-4529-bc96-2c82d9214957"
    }
}
```

